
-- spawn func predefs
local spawn_10man, spawn_25man, spawn_40man, spawn_always

-- objects
-- will be filled with headers/units by name tag 
-- headers["10man"] = {header, header, header, header}
-- :Show and :Hide will be called on them
local objects = {}

-- list of condition, any condition that fits results in its frames being shown.
-- this means you can have multiple raid frame styles active. Just the way I like it.
-- a spawned member will be set on the conditions. If no spawned member is set the spawn function is called.
-- a shown member will be set onthe conditions. If set, the show will not be called
local conditions = {
	{	
		name = "10man",
		min = 1,
		max = 15,
		spawn = spawn_10man,
	},
	{
		name = "25man",
		min = 16,
		max = 35,
		spawn = spawn_25man,
	},
	{
		name = "40man",
		min = 35,
		max = 40,
		spawn = spawn_40man,
	},
	{
		name = "always",
		min = 1,
		max = 40,
		spawn = spawn_always,
	},
}

-- setup
for k, v in pairs(conditions)
	objects[v.name] = {}
end

local pm = CreateFrame("Frame", nil, UIParent)
local function OnEvent(self, event, ...)
	if self[event] then
		self[event](self, event, ...)
	end
end
pm:RegisterEvent("RAID_ROSTER_UPDATE")
pm:RegisterEvent("PLAYER_REGEN_ENABLED")

local checkAfterCombat = nil
local showem, hidem = {}
function pm:RAID_ROSTER_UPDATE()
	if InCombatLockdown() then
		checkAfterCombat = true
		return
	end
	local nr = GetNumRaidMembers()
	for k, v in pairs(conditions)
		if nr >= v.min and nr <= v.max then
			if not v.shown then
				if not v.spawned then v.spawned = v.spawn() end
				if v.spawned then
					for _, object in pairs(objects[v.name]) do
						if object.unit then
							RegisterUnitWatch(object)
							if(UnitExists(object.unit)) then
								object:PLAYER_ENTERING_WORLD()
							end
						else
							object:Show()
						end
					end
					v.shown = true
				end
			end
		elseif v.shown then
			for _, object in pairs(objects[v.name]) do
				if object.unit then
					UnregisterUnitWatch(object)
				end
				object:Hide()				
			end
		end
	end
end

function pm:PLAYER_REGEN_ENABLED()
	if checkAfterCombat then
		checkAfterCombat = nil
		self:RAID_ROSTER_UPDATE()
	end
end

-- spawn functions, should return wether or not they've spawned
-- all spawned unit or header objects should be added to the correct headers[] entry
function spawn_10man()
	-- set style
	oUF:SetActiveStyle("Ammo_Tiny")
	return true
end

function spawn_25man()
	return true
end

function spawn_40man()
	return true
end

function spawn_always()
	return false
end
